Skip to contents

Gets see also, similar, and attribute related synsets/words for adjectives.

Usage

get_Adj_Expansion(synsets, Syns = TRUE)

Arguments

synsets

synsets to obtain the expansion for. May be a single synset or a list of synsets.

Syns

Return the synsets? Defaults to TRUE. If FALSE, returns the various words that make up the synsets.

Value

adjective expansion